@@ -45,13 +45,18 @@ request_step = [
 ]
 
 # 存储途径
-output = {
-    "mongodb": {
-        "host": "47.116.109.99",
-        "port": 27017,
-        "user_name": "",
-        "password": "",
-        "db_name": "competitor_test_data",
+output = [
+    {
+        "mongodb":
+            {
+                "host": "47.116.109.99",
+                "port": 27017,
+                "user_name": "",
+                "password": "",
+                "db_name": "competitor_test_data",
+            },
     },
-    "print": {}
-}
+    {
+        "print": {}
+    }
+]
